==> casagui-0.2.31-py3-none-any.whl: casagui/apps/__init__.py <==
########################################################################
#
# Copyright (C) 2022
# Associated Universities, Inc. Washington DC, USA.
#
# This script is free software; you can redistribute it and/or modify it
# under the terms of the GNU Library General Public License as published by
# the Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# This library is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
# License for more details.
#
# You should have received a copy of the GNU Library General Public License
# along with this library; if not, write to the Free Software Foundation,
# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
#
# Correspondence concerning AIPS++ should be adressed as follows:
#        Internet email: aips2-request@nrao.edu.
#        Postal address: AIPS++ Project Office
#                        National Radio Astronomy Observatory
#                        520 Edgemont Road
#                        Charlottesville, VA 22903-2475 USA
#
########################################################################
'''End user applications supplied by ``casagui``.'''

from ._plotants import plotants
from ._plotbandpass import plotbandpass
from ._makemask import MakeMask
from ._interactiveclean import InteractiveClean, MaskMode
from ..bokeh.state import initialize_session
initialize_session()

==> casagui-0.3.74-py3-none-any.whl: casagui/apps/__init__.py <==
########################################################################
#
# Copyright (C) 2022,2024
# Associated Universities, Inc. Washington DC, USA.
#
# This script is free software; you can redistribute it and/or modify it
# under the terms of the GNU Library General Public License as published by
# the Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# This library is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
# License for more details.
#
# You should have received a copy of the GNU Library General Public License
# along with this library; if not, write to the Free Software Foundation,
# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
#
# Correspondence concerning AIPS++ should be adressed as follows:
#        Internet email: aips2-request@nrao.edu.
#        Postal address: AIPS++ Project Office
#                        National Radio Astronomy Observatory
#                        520 Edgemont Road
#                        Charlottesville, VA 22903-2475 USA
#
########################################################################
'''End user applications supplied by ``casagui``.'''

from ._plotants import plotants
from ._plotbandpass import plotbandpass
from ._makemask import MakeMask
from ._interactiveclean import InteractiveClean
from ..bokeh.state import initialize_session
from ..utils import copydoc
initialize_session()

@copydoc(InteractiveClean)
def run_iclean( *args, **kwargs ):
    ic = InteractiveClean( *args, **kwargs )
    return ic( )
